declare module 'cpp' {
    namespace Cpp {
      /**
       * The Customer object.
       */
      interface Customer {
        /**
         * Merchant id.
         */
        merchantId: string;

        /**
         * Randomly generated customer id.
         */
        customerId: string;

        /**
         * RFC123 timestamp when the customer was created.
         */
        createdTimestamp: string;

        /**
         * RFC123 timestamp when the customer was modified.
         */
        modifiedTimestamp: string;

        /**
         * Customer's name.
         */
        name: string;

        /**
         * Customer's email address.
         */
        emailAddress: string;

        /**
         * Customer's payment methods.
         */
        paymentMethods: Array<Cpp.PaymentMethod> | null;
      }

    //   /**
    //    * The DeletedCustomer object.
    //    */
    //   interface DeletedCustomer {
    //     /**
    //      * Unique identifier for the object.
    //      */
    //     id: string;
  
    //     /**
    //      * String representing the object's type. Objects of the same type share the same value.
    //      */
    //     object: 'customer';
  
    //     /**
    //      * Always true for a deleted object
    //      */
    //     deleted: true;
    //   }
  
      interface CustomerCreateParams {
        /**
         * Customer's email address.
         */
        emailAddress?: string;
  
        /**
         * Customer's name.
         */
        name?: string;
      }
  
    //   interface CustomerRetrieveParams {
    //     /**
    //      * Specifies which fields in the response should be expanded.
    //      */
    //     expand?: Array<string>;
    //   }
  
    //   interface CustomerUpdateParams {
    //     /**
    //      * Customer's email address. It's displayed alongside the customer in your dashboard and can be useful for searching and tracking. This may be up to *512 characters*.
    //      */
    //     emailAddress?: string;
  
    //     /**
    //      * The customer's full name or business name.
    //      */
    //     name?: string;
    //   }
  
    //   interface CustomerDeleteParams {}
  
      class CustomersResource {
        /**
         * Creates a new customer object.
         */
        create(
          params?: CustomerCreateParams,
          options?: RequestOptions
        ): Promise<Cpp.Response<Cpp.Customer>>;
        create(
          options?: RequestOptions
        ): Promise<Cpp.Response<Cpp.Customer>>;
  
        // /**
        //  * Retrieves the details of an existing customer. You need only supply the unique customer identifier that was returned upon customer creation.
        //  */
        // retrieve(
        //   id: string,
        //   params?: CustomerRetrieveParams,
        //   options?: RequestOptions
        // ): Promise<Stripe.Response<Stripe.Customer | Stripe.DeletedCustomer>>;
        // retrieve(
        //   id: string,
        //   options?: RequestOptions
        // ): Promise<Stripe.Response<Stripe.Customer | Stripe.DeletedCustomer>>;
  
        // /**
        //  * Updates the specified customer by setting the values of the parameters passed. Any parameters not provided will be left unchanged. For example, if you pass the source parameter, that becomes the customer's active source (e.g., a card) to be used for all charges in the future. When you update a customer to a new valid card source by passing the source parameter: for each of the customer's current subscriptions, if the subscription bills automatically and is in the past_due state, then the latest open invoice for the subscription with automatic collection enabled will be retried. This retry will not count as an automatic retry, and will not affect the next regularly scheduled payment for the invoice. Changing the default_source for a customer will not trigger this behavior.
        //  *
        //  * This request accepts mostly the same arguments as the customer creation call.
        //  */
        // update(
        //   id: string,
        //   params?: CustomerUpdateParams,
        //   options?: RequestOptions
        // ): Promise<Stripe.Response<Stripe.Customer>>;
  
        // /**
        //  * Returns a list of your customers. The customers are returned sorted by creation date, with the most recent customers appearing first.
        //  */
        // list(
        //   params?: CustomerListParams,
        //   options?: RequestOptions
        // ): ApiListPromise<Stripe.Customer>;
        // list(options?: RequestOptions): ApiListPromise<Stripe.Customer>;
  
        // /**
        //  * Permanently deletes a customer. It cannot be undone. Also immediately cancels any active subscriptions on the customer.
        //  */
        // del(
        //   id: string,
        //   params?: CustomerDeleteParams,
        //   options?: RequestOptions
        // ): Promise<Stripe.Response<Stripe.DeletedCustomer>>;
        // del(
        //   id: string,
        //   options?: RequestOptions
        // ): Promise<Stripe.Response<Stripe.DeletedCustomer>>;
  
        // /**
        //  * Returns a list of PaymentMethods for a given Customer
        //  */
        // listPaymentMethods(
        //   id: string,
        //   params: CustomerListPaymentMethodsParams,
        //   options?: RequestOptions
        // ): ApiListPromise<Stripe.PaymentMethod>;

      }
    }
  }
  